package com.muyu.system.domain.model;

import com.muyu.system.domain.SysMenu;
import com.muyu.system.domain.rep.SysMenuAddReq;
import com.muyu.system.domain.rep.SysMenuListReq;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.util.ArrayList;
import java.util.List;

/**
 * @description: 菜单添加模型
 * @author yangchoashun
 * @date 2025/2/23 17:24
 * @version 1.0
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
public class SysMenuListModel {
    private Long menuId;

    /**
     * 菜单名称
     */
    private String menuName;

    /**
     * 父菜单名称
     */
    private String parentName;

    /**
     * 父菜单ID
     */

    private Long parentId;

    /**
     * 显示顺序
     */

    private Integer orderNum;

    /**
     * 路由地址
     */

    private String path;

    /**
     * 组件路径
     */

    private String component;

    /**
     * 路由参数
     */
    private String query;

    /**
     * 是否为外链（0是 1否）
     */
    private String isFrame;

    /**
     * 是否缓存（0缓存 1不缓存）
     */
    private String isCache;

    /**
     * 类型（M目录 C菜单 F按钮）
     */
    private String menuType;

    /**
     * 显示状态（0显示 1隐藏）
     */
    private String visible;

    /**
     * 菜单状态（0正常 1停用）
     */
    private String status;

    /**
     * 权限字符串
     */
    private String perms;

    /**
     * 菜单图标
     */
    private String icon;

    /**
     * 子菜单
     */
    private List<SysMenu> children = new ArrayList<>();
    public static SysMenuListModel of(SysMenuListReq sysMenuListReq) {
        return SysMenuListModel.builder()
                .menuId(sysMenuListReq.getMenuId())
                .menuName(sysMenuListReq.getMenuName())
                .parentName(sysMenuListReq.getParentName())
                .parentId(sysMenuListReq.getParentId())
                .orderNum(sysMenuListReq.getOrderNum())
                .path(sysMenuListReq.getPath())
                .component(sysMenuListReq.getComponent())
                .query(sysMenuListReq.getQuery())
                .isFrame(sysMenuListReq.getIsFrame())
                .isCache(sysMenuListReq.getIsCache())
                .menuType(sysMenuListReq.getMenuType())
                .visible(sysMenuListReq.getVisible())
                .status(sysMenuListReq.getStatus())
                .perms(sysMenuListReq.getPerms())
                .icon(sysMenuListReq.getIcon())
                .children(sysMenuListReq.getChildren())
                .build();
    }

    public static SysMenuListModel buildSysMenuListModel(SysMenu sysMenu) {
        return SysMenuListModel.builder()
                .menuId(sysMenu.getMenuId())
                .menuName(sysMenu.getMenuName())
                .parentName(sysMenu.getParentName())
                .parentId(sysMenu.getParentId())
                .orderNum(sysMenu.getOrderNum())
                .path(sysMenu.getPath())
                .component(sysMenu.getComponent())
                .query(sysMenu.getQuery())
                .isFrame(sysMenu.getIsFrame())
                .isCache(sysMenu.getIsCache())
                .menuType(sysMenu.getMenuType())
                .visible(sysMenu.getVisible())
                .status(sysMenu.getStatus())
                .perms(sysMenu.getPerms())
                .icon(sysMenu.getIcon())
                .children(sysMenu.getChildren())
                .build();
    }
}
