package com.muyu.system.domain.model;

import com.muyu.system.domain.SysMenu;
import com.muyu.system.domain.rep.SysMenuAddReq;
import com.muyu.system.domain.rep.SysMenuUpdReq;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.util.ArrayList;
import java.util.List;

/**
 * @description: 菜单修改模型
 * @author yangchoashun
 * @date 2025/2/23 17:24
 * @version 1.0
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
public class SysMenuUpdModel {
    /**
     * 菜单ID
     */
    private Long menuId;
    /**
     * 菜单名称
     */
    private String menuName;

    /**
     * 父菜单ID
     */

    private Long parentId;

    /**
     * 显示顺序
     */
    private Integer orderNum;

    /**
     * 路由地址
     */
    private String path;

    /**
     * 组件路径
     */
    private String component;

    /**
     * 路由参数
     */
    private String query;

    /**
     * 是否为外链（0是 1否）
     */
    private String isFrame;

    /**
     * 是否缓存（0缓存 1不缓存）
     */
    private String isCache;

    /**
     * 类型（M目录 C菜单 F按钮）
     */
    private String menuType;

    /**
     * 显示状态（0显示 1隐藏）
     */
    private String visible;

    /**
     * 菜单状态（0正常 1停用）
     */
    private String status;

    /**
     * 权限字符串
     */
    private String perms;

    /**
     * 菜单图标
     */
    private String icon;

    /**
     * 子菜单
     */
    private List<SysMenu> children = new ArrayList<>();

    public static SysMenuUpdModel of(SysMenuUpdReq sysMenuUpdReq) {
        return SysMenuUpdModel.builder()
                .menuName(sysMenuUpdReq.getMenuName())
                .parentId(sysMenuUpdReq.getParentId())
                .orderNum(sysMenuUpdReq.getOrderNum())
                .path(sysMenuUpdReq.getPath())
                .component(sysMenuUpdReq.getComponent())
                .query(sysMenuUpdReq.getQuery())
                .isFrame(sysMenuUpdReq.getIsFrame())
                .isCache(sysMenuUpdReq.getIsCache())
                .menuType(sysMenuUpdReq.getMenuType())
                .visible(sysMenuUpdReq.getVisible())
                .status(sysMenuUpdReq.getStatus())
                .perms(sysMenuUpdReq.getPerms())
                .icon(sysMenuUpdReq.getIcon())
                .children(sysMenuUpdReq.getChildren())
                .build();
    }

}
