package com.muyu.system.domain.model;

import com.muyu.common.core.web.domain.BaseEntity;
import com.muyu.common.core.xss.Xss;
import com.muyu.system.domain.rep.SysNoticeAddReq;
import jakarta.validation.constraints.NotBlank;
import jakarta.validation.constraints.Size;
import lombok.*;
import lombok.experimental.SuperBuilder;

import java.util.Date;
import java.util.function.Supplier;

/**
 * 通知公告添加模型
 *
 * @author 夜は眠れるかい?
 * @Date 2025/2/24 12:25
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@EqualsAndHashCode(callSuper = true)
public class SysNoticeAddModel extends BaseEntity {

    /**
     * 公告ID
     */
    private Long noticeId;

    /**
     * 公告标题
     */
    @Xss(message = "公告标题不能包含脚本字符")
    @NotBlank(message = "公告标题不能为空")
    @Size(min = 0, max = 50, message = "公告标题不能超过50个字符")
    private String noticeTitle;

    /**
     * 公告类型（1通知 2公告）
     */
    private String noticeType;

    /**
     * 公告内容
     */
    private String noticeContent;

    /**
     * 公告状态（0正常 1关闭）
     */
    private String status;

    /**
     * 范围scope
     */
    private String scope;


    /**
     * 将通知公告添加请求对象构建成模型
     *
     * @param sysNoticeAddReq 通知公告添加请求对象
     * @param creatBy 创建人
     * @return 通知公告添加模型
     */
    public static SysNoticeAddModel addReqBuildToModel(SysNoticeAddReq sysNoticeAddReq, Supplier<String> creatBy) {
        return SysNoticeAddModel.builder()
                .noticeTitle(sysNoticeAddReq.getNoticeTitle())
                .noticeType(sysNoticeAddReq.getNoticeType())
                .noticeContent(sysNoticeAddReq.getNoticeContent())
                .status(sysNoticeAddReq.getStatus())
                .scope("若依框架")
                .createBy(creatBy.get())
                .createTime(new Date())
                .build();
    }
}
