package com.muyu.system.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.muyu.common.core.web.page.PageQueryModel;
import com.muyu.common.system.domain.SysDictData;
import com.muyu.system.domain.model.SysDictDataAddModel;
import com.muyu.system.domain.model.SysDictDataPageQueryModel;
import com.muyu.system.domain.model.SysDictDataUpdModel;
import com.muyu.system.domain.rep.SysDictDataUpdReq;

import java.util.List;

/**
 * 字典 业务层
 *
 * @author muyu
 */
public interface SysDictDataService extends IService<SysDictData> {
    /**
     * 根据条件分页查询字典数据
     *
     * @param pageQueryModel 字典数据信息
     *
     * @return 字典数据集合信息
     */
    public PageQueryModel<SysDictData> selectDictDataList (SysDictDataPageQueryModel pageQueryModel);

    /**
     * 根据字典类型和字典键值查询字典数据信息
     *
     * @param dictType  字典类型
     * @param dictValue 字典键值
     *
     * @return 字典标签
     */
    public String selectDictLabel (String dictType, String dictValue);

    /**
     * 根据字典数据ID查询信息
     *
     * @param dictCode 字典数据ID
     *
     * @return 字典数据
     */
    public SysDictData getOneById(Long dictCode);

    /**
     * 批量删除字典数据信息
     *
     * @param dictCodes 需要删除的字典数据ID
     */
    public void deleteDictDataByIds (List<Long> dictCodes);

    /**
     * 新增保存字典数据信息
     *
     * @param sysDictDataAddModel 字典数据信息
     */
    public void insertDictData (SysDictDataAddModel sysDictDataAddModel);

    /**
     * 修改保存字典数据信息
     *
     * @param sysDictDataUpdModel 字典数据信息
     */
    public void updateDictData (SysDictDataUpdModel sysDictDataUpdModel);

    PageQueryModel<SysDictData> pageQuery(SysDictDataPageQueryModel sysDictDataPageQueryModel);

    /**
     * 查询所有非禁用的字典
     * @return 非禁用字典集合
     */
    List<SysDictData> findAllByEnable();

    /**
     * 通过旧的字典类型修改为新字典类型
     * @param oldDictType 旧字典类型
     * @param newDictType 新字典类型
     */
    void updateDictDataType(String oldDictType, String newDictType);

    /**
     * 通过字典类型获取旗下所有字典值
     * @param dictType 字典类型
     * @return 所有字典值集合
     */
    List<SysDictData> selectDictDataByType(String dictType);

    /**
     * 根据字典类型查询字典下总数
     * @param dictType 字典类型
     * @return 总数
     */
    long countDictDataByType(String dictType);
    /**
     * 根据字典类型查询是否有子集
     * @param dictType 字典类型
     * @return 含有：true 不含有：false
     */
    boolean isChildByType(String dictType);
}
