package com.muyu.system.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.muyu.common.core.web.page.DataPageResp;
import com.muyu.common.core.web.page.PageQueryModel;
import com.muyu.system.domain.SysPost;
import com.muyu.system.domain.model.*;
import com.muyu.system.domain.resp.SysPostListResp;

import java.util.List;

/**
 * 岗位信息 服务层
 *
 * @author muyu
 */
public interface SysPostService extends IService<SysPost> {
    /**
     * 查询所有岗位
     *
     * @return 岗位列表
     */
    public List<SysPost> selectPostAll ();

    /**
     * 通过岗位ID查询岗位信息
     *
     * @param postId 岗位ID
     *
     * @return 角色对象信息
     */
    public SysPostMyInfoModel selectPostById (Long postId);

    /**
     * 根据用户ID获取岗位选择框列表
     *
     * @param userId 用户ID
     *
     * @return 选中岗位ID列表
     */
    public List<Long> selectPostListByUserId (Long userId);

    /**
     * 校验岗位名称
     *
     * @param sysPostSaveModel 岗位信息
     *
     * @return 结果
     */
    public boolean checkPostNameUnique (SysPostSaveModel sysPostSaveModel);/**


     * 校验岗位名称
     *
     * @param sysPostEditModel 岗位信息
     *
     * @return 结果
     */
    public boolean checkEditPostNameUnique (SysPostEditModel sysPostEditModel);


    /**
     * 校验岗位编码
     *
     * @param sysPostSaveModel 岗位信息
     *
     * @return 结果
     */
    public boolean checkPostCodeUnique (SysPostSaveModel sysPostSaveModel);


    /**
     * 校验岗位编码
     *
     * @param sysPostEditModel 岗位信息
     *
     * @return 结果
     */
    public boolean checkEditPostCodeUnique (SysPostEditModel sysPostEditModel);

    /**
     * 通过岗位ID查询岗位使用数量
     *
     * @param postId 岗位ID
     *
     * @return 结果
     */
    public long countUserPostById (Long postId);

    /**
     * 删除岗位信息
     *
     * @param postId 岗位ID
     *
     * @return 结果
     */
    public void deletePostById (Long postId);

    /**
     * 批量删除岗位信息
     *
     * @param postIds 需要删除的岗位ID
     *
     * @return 结果
     */
    public void deletePostByIds (List<Long> postIds);

    /**
     * 新增保存岗位信息
     *
     * @param post 岗位信息
     *
     * @return 结果
     */
    public void insertPost (SysPost post);

    /**
     * 修改保存岗位信息
     *
     * @param post 岗位信息
     *
     * @return 结果
     */
    public void updatePost (SysPost post);

    PageQueryModel<SysPost> pageQuery(SysPostPageQueryModel sysPostPageQueryModel);

    /**
     * 岗位信息列表
     * @param sysPostPageQueryModel 分页信息
     * @return 结果
     */
    PageQueryModel<SysPostListModel> getList(SysPostPageQueryModel sysPostPageQueryModel);
}
